RustyCommand

Enum RustyCommand 

pub enum RustyCommand {
    Deploy {
        name: String,
        synth_path: Option<String>,
        cleanup: bool,
    },
    Diff {
        name: String,
        synth_path: Option<String>,
        cleanup: bool,
    },
    Destroy {
        name: String,
        force: bool,
    },
}

Variants



Deploy

Fields

name: String

Name of the stack when it’s deployed

synth_path: Option<String>

Path of synthesized stack relative to the current directory If no path is passed in, the command will generate a synthesized stack using cargo run

cleanup: bool

Cleans up the generated or passed-in synth file



Diff

Fields

name: String

Name of the (deployed) stack that you want to compare with

synth_path: Option<String>

Path of synthesized stack relative to the current directory If no path is passed in, the command will generate a synthesized stack using cargo run

cleanup: bool

Cleans up the generated or passed-in synth file



Destroy

Fields

name: String

Name of the (deployed) stack that you want to delete

force: bool

Force tries to make sure your stack deletes, avoiding common things that can throw a DeleteFailed error. To do this, force will: empty S3 buckets that do not have a ‘retain’ and remove archival policies from SNS topics Resources with a ‘retain’ policy are ignored. Use with caution, and only if you don’t need to retain anything from your stack that is not set to ‘retain’