pub enum RustyCommand {
Deploy {
name: String,
synth_path: Option<String>,
cleanup: bool,
},
Diff {
name: String,
synth_path: Option<String>,
cleanup: bool,
},
Destroy {
name: String,
force: bool,
},
}Variants
Deploy
Fields
Diff
Fields
Destroy
Fields

force: boolForce tries to make sure your stack deletes, avoiding common things that can throw a DeleteFailed error.
To do this, force will: empty S3 buckets that do not have a ‘retain’ and remove archival policies from SNS topics
Resources with a ‘retain’ policy are ignored.
Use with caution, and only if you don’t need to retain anything from your stack that is not set to ‘retain’